@@ -126,7 +126,26 @@ function ramcms_remove_body_whitespace($body)
 #
 function ramcms_page_template_parser($page_template,$title,$site_name,$header,$updated_show,$body,$copyright)
 {
+	global $PHP_SELF,$SERVER_NAME,$HTTPS;
 	# parse the $page_template information.
+	$protocol='http://';
+	if(isset($_SERVER['HTTPS'])==true && strtolower($_SERVER['HTTPS'])=='on')
+	{
+		$protocol='https://';
+	}
+	elseif(isset($HTTPS)==true && strtolower($HTTPS)=='on')
+	{
+		$protocol='https://';
+	}
+	# parse the $page_template information.
+	if(isset($_SERVER['SERVER_NAME'])==true && isset($_SERVER['PHP_SELF'])==true)
+	{
+	$page_template=str_replace('[[baseurl]]',$protocol.$_SERVER['SERVER_NAME'].dirname($_SERVER['PHP_SELF'].'/').'/',$page_template);
+	}
+	else
+	{
+	$page_template=str_replace('[[baseurl]]',$protocol.$SERVER_NAME.dirname($PHP_SELF.'/').'/',$page_template);
+	}
 	$page_template=str_replace('[[body]]',$body,$page_template);
 	$page_template=str_replace('[[copyright]]',$copyright,$page_template);
 	$page_template=str_replace('[[header]]',$header,$page_template);
@@ -134,7 +153,7 @@ function ramcms_page_template_parser($page_template,$title,$site_name,$header,$u
 	$page_template=str_replace('[[site]]',$site_name,$page_template);
 	$page_template=str_replace('[[title]]',$title,$page_template);
 	$page_template=str_replace('[[updated]]',$updated_show,$page_template);
-	$page_template=str_replace('[[ver]]','0.2.0',$page_template);
+	$page_template=str_replace('[[ver]]','0.2.5',$page_template);
 	
 	return $page_template;
 }
@@ -219,6 +238,14 @@ function ramcms_bbcode_parser($body)
 	
 	### Complex BBCode ###
 	
+	# handles [url]internal-page[/url]
+	$body=preg_replace('/\[link\](.+)\[\/link\]/U','<a href="./?page=${1}">${1}</a>',$body);
+	
+	# handles [url=internal-page]My Internal Page[/url]
+	$pattern='/\[link=(.+)\](.+)\[\/link\]/U';
+	$replacement='<a href="./?page=${1}">${2}</a>';
+	$body=preg_replace($pattern,$replacement,$body);
+	
 	# handles [url]http://example.com/blah..[/url]
 	$body=preg_replace('/\[url\](.+)\[\/url\]/U','<a href="${1}">${1}</a>',$body);
 	
